@@ -1,7 +1,7 @@
 package cmd
 
 import (
-	"github.com/miguelmota/cointop/cointop"
+	"github.com/cointop-sh/cointop/cointop"
 	"github.com/spf13/cobra"
 )
 
