@@ -10,10 +10,24 @@ import (
 
 // CacheKey returns cached value given key
 func (ct *Cointop) CacheKey(key string) string {
-	log.Debug("CacheKey()")
 	return strings.ToLower(fmt.Sprintf("%s_%s", ct.apiChoice, key))
 }
 
+// CompositeCacheKey returns a CacheKey for a coin (or globaldata)
+func (ct *Cointop) CompositeCacheKey(symbol string, name string, convert string, chartRange string) string {
+	keyname := symbol
+	if name != "" {
+		keyname += "-" + name
+	}
+	if convert != "" {
+		keyname += "_" + convert
+	}
+	if chartRange != "" {
+		keyname += "_" + strings.Replace(chartRange, " ", "", -1) // "All Time" contains space
+	}
+	return ct.CacheKey(keyname)
+}
+
 // CacheAllCoinsSlugMap writes the coins map to the memory and disk cache
 func (ct *Cointop) CacheAllCoinsSlugMap() {
 	log.Debug("CacheAllCoinsSlugMap()")
