@@ -11,9 +11,10 @@ import (
 	"strconv"
 	"strings"
 	"time"
+	"unicode/utf8"
 
-	"github.com/miguelmota/cointop/pkg/pathutil"
-	"github.com/miguelmota/cointop/pkg/toml"
+	"github.com/cointop-sh/cointop/pkg/pathutil"
+	"github.com/cointop-sh/cointop/pkg/toml"
 	log "github.com/sirupsen/logrus"
 )
 
@@ -23,7 +24,7 @@ var FilePerm = os.FileMode(0644)
 // ErrInvalidPriceAlert is error for invalid price alert value
 var ErrInvalidPriceAlert = errors.New("invalid price alert value")
 
-// PossibleConfigPaths are the the possible config file paths.
+// PossibleConfigPaths are the possible config file paths.
 // NOTE: this is to support previous default config filepaths
 var PossibleConfigPaths = []string{
 	":PREFERRED_CONFIG_HOME:/cointop/config.toml",
@@ -47,56 +48,38 @@ type ConfigFileConfig struct {
 	Colorscheme       interface{}            `toml:"colorscheme"`
 	RefreshRate       interface{}            `toml:"refresh_rate"`
 	CacheDir          interface{}            `toml:"cache_dir"`
+	CompactNotation   interface{}            `toml:"compact_notation"`
 	Table             map[string]interface{} `toml:"table"`
+	Chart             map[string]interface{} `toml:"chart"`
 }
 
 // SetupConfig loads config file
 func (ct *Cointop) SetupConfig() error {
-	log.Debug("SetupConfig()")
-	if err := ct.CreateConfigIfNotExists(); err != nil {
-		return err
+	type loadConfigFunc func() error
+	loaders := []loadConfigFunc{
+		ct.CreateConfigIfNotExists,
+		ct.ParseConfig,
+		ct.loadTableConfig,
+		ct.loadChartConfig,
+		ct.loadShortcutsFromConfig,
+		ct.loadFavoritesFromConfig,
+		ct.loadCurrencyFromConfig,
+		ct.loadDefaultViewFromConfig,
+		ct.loadDefaultChartRangeFromConfig,
+		ct.loadAPIKeysFromConfig,
+		ct.loadAPIChoiceFromConfig,
+		ct.loadColorschemeFromConfig,
+		ct.loadRefreshRateFromConfig,
+		ct.loadCacheDirFromConfig,
+		ct.loadCompactNotationFromConfig,
+		ct.loadPriceAlertsFromConfig,
+		ct.loadPortfolioFromConfig,
 	}
-	if err := ct.ParseConfig(); err != nil {
-		return err
-	}
-	if err := ct.loadTableConfig(); err != nil {
-		return err
-	}
-	if err := ct.loadShortcutsFromConfig(); err != nil {
-		return err
-	}
-	if err := ct.loadFavoritesFromConfig(); err != nil {
-		return err
-	}
-	if err := ct.loadCurrencyFromConfig(); err != nil {
-		return err
-	}
-	if err := ct.loadDefaultViewFromConfig(); err != nil {
-		return err
-	}
-	if err := ct.loadDefaultChartRangeFromConfig(); err != nil {
-		return err
-	}
-	if err := ct.loadAPIKeysFromConfig(); err != nil {
-		return err
-	}
-	if err := ct.loadAPIChoiceFromConfig(); err != nil {
-		return err
-	}
-	if err := ct.loadColorschemeFromConfig(); err != nil {
-		return err
-	}
-	if err := ct.loadRefreshRateFromConfig(); err != nil {
-		return err
-	}
-	if err := ct.loadCacheDirFromConfig(); err != nil {
-		return err
-	}
-	if err := ct.loadPriceAlertsFromConfig(); err != nil {
-		return err
-	}
-	if err := ct.loadPortfolioFromConfig(); err != nil {
-		return err
+
+	for _, f := range loaders {
+		if err := f(); err != nil {
+			return err
+		}
 	}
 
 	return nil
@@ -147,7 +130,7 @@ func (ct *Cointop) ConfigFilePath() string {
 	return pathutil.NormalizePath(ct.configFilepath)
 }
 
-// ConfigPath return the config file path
+// MakeConfigDir creates the directory for the config file
 func (ct *Cointop) MakeConfigDir() error {
 	log.Debug("MakeConfigDir()")
 	path := ct.ConfigDirPath()
@@ -234,46 +217,37 @@ func (ct *Cointop) ConfigToToml() ([]byte, error) {
 	var favoritesBySymbolIfc []interface{}
 	favoritesMapIfc := map[string]interface{}{
 		// DEPRECATED: favorites by 'symbol' is deprecated because of collisions. Kept for backward compatibility.
-		"symbols": favoritesBySymbolIfc,
-		"names":   favoritesIfc,
+		"symbols":          favoritesBySymbolIfc,
+		"names":            favoritesIfc,
+		"columns":          ct.State.favoritesTableColumns,
+		"character":        ct.State.favoriteChar,
+		"compact_notation": ct.State.favoritesCompactNotation,
 	}
 
-	var favoritesColumnsIfc interface{} = ct.State.favoritesTableColumns
-	favoritesMapIfc["columns"] = favoritesColumnsIfc
-
-	portfolioIfc := map[string]interface{}{}
 	var holdingsIfc [][]string
 	for name := range ct.State.portfolio.Entries {
 		entry, ok := ct.State.portfolio.Entries[name]
 		if !ok || entry.Coin == "" {
 			continue
 		}
-		var amount string = strconv.FormatFloat(entry.Holdings, 'f', -1, 64)
-		var coinName string = entry.Coin
-		var tuple []string = []string{coinName, amount}
+		amount := strconv.FormatFloat(entry.Holdings, 'f', -1, 64)
+		coinName := entry.Coin
+		tuple := []string{coinName, amount}
 		holdingsIfc = append(holdingsIfc, tuple)
 	}
 	sort.Slice(holdingsIfc, func(i, j int) bool {
 		return holdingsIfc[i][0] < holdingsIfc[j][0]
 	})
-	portfolioIfc["holdings"] = holdingsIfc
-
-	var columnsIfc interface{} = ct.State.portfolioTableColumns
-	portfolioIfc["columns"] = columnsIfc
-
-	var currencyIfc interface{} = ct.State.currencyConversion
-	var defaultViewIfc interface{} = ct.State.defaultView
-	var defaultChartRangeIfc interface{} = ct.State.defaultChartRange
-	var colorschemeIfc interface{} = ct.colorschemeName
-	var refreshRateIfc interface{} = uint(ct.State.refreshRate.Seconds())
-	var cacheDirIfc interface{} = ct.State.cacheDir
+	portfolioIfc := map[string]interface{}{
+		"holdings":         holdingsIfc,
+		"columns":          ct.State.portfolioTableColumns,
+		"compact_notation": ct.State.portfolioCompactNotation,
+	}
 
 	cmcIfc := map[string]interface{}{
 		"pro_api_key": ct.apiKeys.cmc,
 	}
 
-	var apiChoiceIfc interface{} = ct.apiChoice
-
 	var priceAlertsIfc []interface{}
 	for _, priceAlert := range ct.State.priceAlerts.Entries {
 		if priceAlert.Expired {
@@ -291,26 +265,33 @@ func (ct *Cointop) ConfigToToml() ([]byte, error) {
 		//"sound":  ct.State.priceAlerts.SoundEnabled,
 	}
 
-	var coinsTableColumnsIfc interface{} = ct.State.coinsTableColumns
-	tableMapIfc := map[string]interface{}{}
-	tableMapIfc["columns"] = coinsTableColumnsIfc
-	var keepRowFocusOnSortIfc interface{} = ct.State.keepRowFocusOnSort
-	tableMapIfc["keep_row_focus_on_sort"] = keepRowFocusOnSortIfc
+	tableMapIfc := map[string]interface{}{
+		"columns":                ct.State.coinsTableColumns,
+		"keep_row_focus_on_sort": ct.State.keepRowFocusOnSort,
+		"compact_notation":       ct.State.tableCompactNotation,
+	}
+
+	chartMapIfc := map[string]interface{}{
+		"max_width": ct.State.maxChartWidth,
+		"height":    ct.State.chartHeight,
+	}
 
 	var inputs = &ConfigFileConfig{
-		API:               apiChoiceIfc,
-		Colorscheme:       colorschemeIfc,
+		API:               ct.apiChoice,
+		Colorscheme:       ct.colorschemeName,
 		CoinMarketCap:     cmcIfc,
-		Currency:          currencyIfc,
-		DefaultView:       defaultViewIfc,
-		DefaultChartRange: defaultChartRangeIfc,
+		Currency:          ct.State.currencyConversion,
+		DefaultView:       ct.State.defaultView,
+		DefaultChartRange: ct.State.defaultChartRange,
 		Favorites:         favoritesMapIfc,
-		RefreshRate:       refreshRateIfc,
+		RefreshRate:       uint(ct.State.refreshRate.Seconds()),
 		Shortcuts:         shortcutsIfcs,
 		Portfolio:         portfolioIfc,
 		PriceAlerts:       priceAlertsMapIfc,
-		CacheDir:          cacheDirIfc,
+		CacheDir:          ct.State.cacheDir,
 		Table:             tableMapIfc,
+		Chart:             chartMapIfc,
+		CompactNotation:   ct.State.compactNotation,
 	}
 
 	var b bytes.Buffer
@@ -335,6 +316,27 @@ func (ct *Cointop) loadTableConfig() error {
 	if ok {
 		ct.State.keepRowFocusOnSort = keepRowFocusOnSortIfc.(bool)
 	}
+
+	if compactNotation, ok := ct.config.Table["compact_notation"]; ok {
+		ct.State.tableCompactNotation = compactNotation.(bool)
+	}
+
+	return nil
+}
+
+// LoadChartConfig loads chart config from toml config into state struct
+func (ct *Cointop) loadChartConfig() error {
+	log.Debugf("loadChartConfig()")
+	maxChartWidthIfc, ok := ct.config.Chart["max_width"]
+	if ok {
+		ct.State.maxChartWidth = int(maxChartWidthIfc.(int64))
+	}
+
+	chartHeightIfc, ok := ct.config.Chart["height"]
+	if ok {
+		ct.State.chartHeight = int(chartHeightIfc.(int64))
+		ct.State.lastChartHeight = ct.State.chartHeight
+	}
 	return nil
 }
 
@@ -467,6 +469,16 @@ func (ct *Cointop) loadCacheDirFromConfig() error {
 	return nil
 }
 
+// loadCompactNotationFromConfig loads compact-notation setting from config file to struct
+func (ct *Cointop) loadCompactNotationFromConfig() error {
+	log.Debug("loadCompactNotationFromConfig()")
+	if compactNotation, ok := ct.config.CompactNotation.(bool); ok {
+		ct.State.compactNotation = compactNotation
+	}
+
+	return nil
+}
+
 // LoadAPIChoiceFromConfig loads API choices from config file to struct
 func (ct *Cointop) loadAPIChoiceFromConfig() error {
 	log.Debug("loadAPIKeysFromConfig()")
@@ -482,6 +494,16 @@ func (ct *Cointop) loadAPIChoiceFromConfig() error {
 func (ct *Cointop) loadFavoritesFromConfig() error {
 	log.Debug("loadFavoritesFromConfig()")
 	for k, valueIfc := range ct.config.Favorites {
+		if k == "character" {
+			if favoriteChar, ok := valueIfc.(string); ok {
+				if utf8.RuneCountInString(favoriteChar) != 1 {
+					return fmt.Errorf("invalid favorite-character. Must be one-character")
+				}
+				ct.State.favoriteChar = favoriteChar
+			}
+		} else if k == "compact_notation" {
+			ct.State.favoritesCompactNotation = valueIfc.(bool)
+		}
 		ifcs, ok := valueIfc.([]interface{})
 		if !ok {
 			continue
@@ -569,6 +591,8 @@ func (ct *Cointop) loadPortfolioFromConfig() error {
 					return err
 				}
 			}
+		} else if key == "compact_notation" {
+			ct.State.portfolioCompactNotation = valueIfc.(bool)
 		} else {
 			// Backward compatibility < v1.6.0
 			holdings, err := ct.InterfaceToFloat64(valueIfc)
@@ -645,7 +669,7 @@ func (ct *Cointop) loadPriceAlertsFromConfig() error {
 	return nil
 }
 
-// GetColorschemeColors loads colors from colorsheme file to struct
+// GetColorschemeColors loads colors from colorscheme file to struct
 func (ct *Cointop) GetColorschemeColors() (map[string]interface{}, error) {
 	log.Debug("GetColorschemeColors()")
 	var colors map[string]interface{}
