@@ -6,8 +6,9 @@ import (
 	"sort"
 	"strings"
 
-	color "github.com/miguelmota/cointop/pkg/color"
-	"github.com/miguelmota/cointop/pkg/pad"
+	"github.com/cointop-sh/cointop/pkg/color"
+	"github.com/cointop-sh/cointop/pkg/pad"
+	"github.com/mattn/go-runewidth"
 	log "github.com/sirupsen/logrus"
 )
 
@@ -56,53 +57,55 @@ var FiatCurrencyNames = map[string]string{
 
 // CryptocurrencyNames is a map of cryptocurrency symbols to name
 var CryptocurrencyNames = map[string]string{
-	"BTC": "Bitcoin",
-	"ETH": "Ethereum",
+	"BTC":  "Bitcoin",
+	"ETH":  "Ethereum",
+	"SATS": "Satoshi",
 }
 
 // CurrencySymbolMap is map of fiat currency symbols to names.
 // Keep these in alphabetical order.
 var CurrencySymbolMap = map[string]string{
-	"AUD": "$",
-	"BGN": "Лв.",
-	"BRL": "R$",
-	"BTC": "Ƀ",
-	"CAD": "$",
-	"CFH": "₣",
-	"CLP": "$",
-	"CNY": "¥",
-	"CZK": "Kč",
-	"DKK": "Kr",
-	"ETH": "Ξ",
-	"EUR": "€",
-	"GBP": "£",
-	"HKD": "$",
-	"HRK": "kn",
-	"HUF": "Ft",
-	"IDR": "Rp.",
-	"ILS": "₪",
-	"INR": "₹",
-	"ISK": "kr",
-	"JPY": "¥",
-	"KRW": "₩",
-	"MXN": "$",
-	"MYR": "RM",
-	"NOK": "kr",
-	"NZD": "$",
-	"PHP": "₱",
-	"PKR": "₨",
-	"PLN": "zł",
-	"RON": "lei",
-	"RUB": "Ꝑ",
-	"SEK": "kr",
-	"SGD": "S$",
-	"THB": "฿",
-	"TRY": "₺",
-	"TWD": "NT$",
-	"UAH": "₴",
-	"USD": "$",
-	"VND": "₫",
-	"ZAR": "R",
+	"AUD":  "$",
+	"BGN":  "Лв.",
+	"BRL":  "R$",
+	"BTC":  "Ƀ",
+	"CAD":  "$",
+	"CFH":  "₣",
+	"CLP":  "$",
+	"CNY":  "¥",
+	"CZK":  "Kč",
+	"DKK":  "Kr",
+	"ETH":  "Ξ",
+	"EUR":  "€",
+	"GBP":  "£",
+	"HKD":  "$",
+	"HRK":  "kn",
+	"HUF":  "Ft",
+	"IDR":  "Rp.",
+	"ILS":  "₪",
+	"INR":  "₹",
+	"ISK":  "kr",
+	"JPY":  "¥",
+	"KRW":  "₩",
+	"MXN":  "$",
+	"MYR":  "RM",
+	"NOK":  "kr",
+	"NZD":  "$",
+	"PHP":  "₱",
+	"PKR":  "₨",
+	"PLN":  "zł",
+	"RON":  "lei",
+	"RUB":  "Ꝑ",
+	"SEK":  "kr",
+	"SGD":  "S$",
+	"SATS": "丰",
+	"THB":  "฿",
+	"TRY":  "₺",
+	"TWD":  "NT$",
+	"UAH":  "₴",
+	"USD":  "$",
+	"VND":  "₫",
+	"ZAR":  "R",
 }
 
 var alphanumericcharacters = []rune{'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z', 'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z'}
@@ -247,7 +250,14 @@ func (ct *Cointop) SetCurrencyConverstionFn(convert string) func() error {
 // CurrencySymbol returns the symbol for the currency conversion
 func (ct *Cointop) CurrencySymbol() string {
 	log.Debug("CurrencySymbol()")
-	return CurrencySymbol(ct.State.currencyConversion)
+	symbol := CurrencySymbol(ct.State.currencyConversion)
+
+	width := runewidth.StringWidth(symbol)
+	if width > 1 {
+		symbol = pad.Right(symbol, width, " ")
+	}
+
+	return symbol
 }
 
 // ShowConvertMenu shows the convert menu view
