@@ -413,7 +413,7 @@ func (ct *Cointop) GoToGlobalIndex(idx int) error {
 	l := ct.TableRowsLen()
 	atpage := idx / l
 	ct.SetPage(atpage)
-	rowIndex := (idx % l)
+	rowIndex := idx % l
 	ct.HighlightRow(rowIndex)
 	ct.UpdateTable()
 	return nil
@@ -537,7 +537,7 @@ func (ct *Cointop) TableScrollLeft() error {
 	return nil
 }
 
-// TableScrollRight scrolls the the table to the right
+// TableScrollRight scrolls the table to the right
 func (ct *Cointop) TableScrollRight() error {
 	ct.State.tableOffsetX--
 	maxX := int(math.Min(float64(1-(ct.maxTableWidth-ct.Width())), 0))
