@@ -12,11 +12,11 @@ import (
 	"time"
 	"unicode/utf8"
 
-	"github.com/miguelmota/cointop/pkg/asciitable"
-	"github.com/miguelmota/cointop/pkg/eval"
-	"github.com/miguelmota/cointop/pkg/humanize"
-	"github.com/miguelmota/cointop/pkg/pad"
-	"github.com/miguelmota/cointop/pkg/table"
+	"github.com/cointop-sh/cointop/pkg/asciitable"
+	"github.com/cointop-sh/cointop/pkg/eval"
+	"github.com/cointop-sh/cointop/pkg/humanize"
+	"github.com/cointop-sh/cointop/pkg/pad"
+	"github.com/cointop-sh/cointop/pkg/table"
 	log "github.com/sirupsen/logrus"
 )
 
@@ -78,8 +78,8 @@ func (ct *Cointop) GetPortfolioTable() *table.Table {
 	t := table.NewTable().SetWidth(maxX)
 	var rows [][]*table.RowCell
 	headers := ct.GetPortfolioTableHeaders()
-	ct.ClearSyncMap(ct.State.tableColumnWidths)
-	ct.ClearSyncMap(ct.State.tableColumnAlignLeft)
+	ct.ClearSyncMap(&ct.State.tableColumnWidths)
+	ct.ClearSyncMap(&ct.State.tableColumnAlignLeft)
 	for _, coin := range ct.State.coins {
 		leftMargin := 1
 		rightMargin := 1
@@ -89,7 +89,7 @@ func (ct *Cointop) GetPortfolioTable() *table.Table {
 			case "rank":
 				star := ct.colorscheme.TableRow(" ")
 				if coin.Favorite {
-					star = ct.colorscheme.TableRowFavorite("*")
+					star = ct.colorscheme.TableRowFavorite(ct.State.favoriteChar)
 				}
 				rank := fmt.Sprintf("%s%v", star, ct.colorscheme.TableRow(fmt.Sprintf("%6v ", coin.Rank)))
 				ct.SetTableColumnWidth(header, 8)
@@ -290,7 +290,7 @@ func (ct *Cointop) GetPortfolioTable() *table.Table {
 					})
 			case "last_updated":
 				unix, _ := strconv.ParseInt(coin.LastUpdated, 10, 64)
-				lastUpdated := time.Unix(unix, 0).Format("15:04:05 Jan 02")
+				lastUpdated := humanize.FormatTime(time.Unix(unix, 0), "15:04:05 Jan 02")
 				ct.SetTableColumnWidthFromString(header, lastUpdated)
 				ct.SetTableColumnAlignLeft(header, false)
 				rowCells = append(rowCells,
@@ -555,7 +555,7 @@ func (ct *Cointop) PortfolioEntriesCount() int {
 // GetPortfolioSlice returns portfolio entries as a slice
 func (ct *Cointop) GetPortfolioSlice() []*Coin {
 	log.Debug("GetPortfolioSlice()")
-	sliced := []*Coin{}
+	var sliced []*Coin
 	if ct.PortfolioEntriesCount() == 0 {
 		return sliced
 	}
@@ -983,19 +983,16 @@ func (ct *Cointop) PrintHoldings24HChange(options *TablePrintOptions) error {
 			}
 		}
 
-		n := ((entry.Balance / total) * entry.PercentChange24H)
+		n := (entry.Balance / total) * entry.PercentChange24H
 		if math.IsNaN(n) {
 			continue
 		}
 		percentChange24H += n
 	}
 
-	value := strconv.FormatFloat(percentChange24H, 'f', -1, 64)
-
+	value := fmt.Sprintf("%.2f", percentChange24H)
 	if humanReadable {
-		value = fmt.Sprintf("%.2f%%", percentChange24H)
-	} else {
-		value = fmt.Sprintf("%.2f", percentChange24H)
+		value = fmt.Sprintf("%s%%", value)
 	}
 
 	if format == "csv" {
