@@ -6,8 +6,8 @@ import (
 	"strings"
 	"unicode/utf8"
 
-	"github.com/miguelmota/cointop/pkg/pad"
-	"github.com/miguelmota/cointop/pkg/ui"
+	"github.com/cointop-sh/cointop/pkg/pad"
+	"github.com/cointop-sh/cointop/pkg/ui"
 	log "github.com/sirupsen/logrus"
 )
 
@@ -21,115 +21,128 @@ var ArrowDown = "▼"
 type HeaderColumn struct {
 	Slug       string
 	Label      string
+	ShortLabel string // only columns with a ShortLabel can be scaled?
 	PlainLabel string
 }
 
 // HeaderColumns are the header column widths
 var HeaderColumns = map[string]*HeaderColumn{
-	"rank": &HeaderColumn{
+	"rank": {
 		Slug:       "rank",
 		Label:      "[r]ank",
 		PlainLabel: "rank",
 	},
-	"name": &HeaderColumn{
+	"name": {
 		Slug:       "name",
 		Label:      "[n]ame",
 		PlainLabel: "name",
 	},
-	"symbol": &HeaderColumn{
+	"symbol": {
 		Slug:       "symbol",
 		Label:      "[s]ymbol",
 		PlainLabel: "symbol",
 	},
-	"target_price": &HeaderColumn{
+	"target_price": {
 		Slug:       "target_price",
 		Label:      "[t]target price",
 		PlainLabel: "target price",
 	},
-	"price": &HeaderColumn{
+	"price": {
 		Slug:       "price",
 		Label:      "[p]rice",
 		PlainLabel: "price",
 	},
-	"frequency": &HeaderColumn{
+	"frequency": {
 		Slug:       "frequency",
 		Label:      "frequency",
 		PlainLabel: "frequency",
 	},
-	"holdings": &HeaderColumn{
+	"holdings": {
 		Slug:       "holdings",
 		Label:      "[h]oldings",
 		PlainLabel: "holdings",
 	},
-	"balance": &HeaderColumn{
+	"balance": {
 		Slug:       "balance",
 		Label:      "[b]alance",
 		PlainLabel: "balance",
 	},
-	"market_cap": &HeaderColumn{
+	"market_cap": {
 		Slug:       "market_cap",
 		Label:      "[m]arket cap",
+		ShortLabel: "[m]cap",
 		PlainLabel: "market cap",
 	},
-	"24h_volume": &HeaderColumn{
+	"24h_volume": {
 		Slug:       "24h_volume",
 		Label:      "24H [v]olume",
+		ShortLabel: "24[v]",
 		PlainLabel: "24H volume",
 	},
-	"1h_change": &HeaderColumn{
+	"1h_change": {
 		Slug:       "1h_change",
 		Label:      "[1]H%",
 		PlainLabel: "1H%",
 	},
-	"24h_change": &HeaderColumn{
+	"24h_change": {
 		Slug:       "24h_change",
 		Label:      "[2]4H%",
 		PlainLabel: "24H%",
 	},
-	"7d_change": &HeaderColumn{
+	"7d_change": {
 		Slug:       "7d_change",
 		Label:      "[7]D%",
 		PlainLabel: "7D%",
 	},
-	"30d_change": &HeaderColumn{
+	"30d_change": {
 		Slug:       "30d_change",
 		Label:      "[3]0D%",
 		PlainLabel: "30D%",
 	},
-	"1y_change": &HeaderColumn{
+	"1y_change": {
 		Slug:       "1y_change",
 		Label:      "1[y]%",
 		PlainLabel: "1Y%",
 	},
-	"total_supply": &HeaderColumn{
+	"total_supply": {
 		Slug:       "total_supply",
 		Label:      "[t]otal supply",
+		ShortLabel: "[t]ot",
 		PlainLabel: "total supply",
 	},
-	"available_supply": &HeaderColumn{
+	"available_supply": {
 		Slug:       "available_supply",
 		Label:      "[a]vailable supply",
+		ShortLabel: "[a]vl",
 		PlainLabel: "available supply",
 	},
-	"percent_holdings": &HeaderColumn{
+	"percent_holdings": {
 		Slug:       "percent_holdings",
 		Label:      "[%]holdings",
 		PlainLabel: "%holdings",
 	},
-	"last_updated": &HeaderColumn{
+	"last_updated": {
 		Slug:       "last_updated",
 		Label:      "last [u]pdated",
 		PlainLabel: "last updated",
 	},
 }
 
+// GetLabel fetch the label to use for the heading (depends on configuration)
+func (ct *Cointop) GetLabel(h *HeaderColumn) string {
+	// TODO: technically this should support nosort
+	if ct.IsActiveTableCompactNotation() && h.ShortLabel != "" {
+		return h.ShortLabel
+	}
+	return h.Label
+}
+
 // TableHeaderView is structure for table header view
 type TableHeaderView = ui.View
 
 // NewTableHeaderView returns a new table header view
 func NewTableHeaderView() *TableHeaderView {
-	var view *TableHeaderView = ui.NewView("table_header")
-	return view
+	return ui.NewView("table_header")
 }
 
 // GetActiveTableHeaders returns the list of active table headers
@@ -146,6 +159,22 @@ func (ct *Cointop) GetActiveTableHeaders() []string {
 	return cols
 }
 
+// GetActiveTableHeaders returns the list of active table headers
+func (ct *Cointop) IsActiveTableCompactNotation() bool {
+	var compact bool
+	switch ct.State.selectedView {
+	case PortfolioView:
+		compact = ct.State.portfolioCompactNotation
+	case CoinsView:
+		compact = ct.State.tableCompactNotation
+	case FavoritesView:
+		compact = ct.State.favoritesCompactNotation
+	default:
+		compact = ct.State.tableCompactNotation
+	}
+	return compact
+}
+
 // UpdateTableHeader renders the table header
 func (ct *Cointop) UpdateTableHeader() error {
 	log.Debug("UpdateTableHeader()")
@@ -176,14 +205,14 @@ func (ct *Cointop) UpdateTableHeader() error {
 				}
 			}
 		}
-		label := hc.Label
+		label := ct.GetLabel(hc)
 		if noSort {
 			label = hc.PlainLabel
 		}
 		leftAlign := ct.GetTableColumnAlignLeft(col)
 		switch col {
 		case "price", "balance":
-			label = ct.CurrencySymbol() + label
+			label = fmt.Sprintf("%s%s", ct.CurrencySymbol(), label)
 		}
 		if leftAlign {
 			label = label + arrow
@@ -236,7 +265,7 @@ func (ct *Cointop) SetTableColumnWidth(header string, width int) {
 		prev = prevIfc.(int)
 	} else {
 		hc := HeaderColumns[header]
-		prev = utf8.RuneCountInString(hc.Label) + 1
+		prev = utf8.RuneCountInString(ct.GetLabel(hc)) + 1
 		switch header {
 		case "price", "balance":
 			prev++
