@@ -8,7 +8,7 @@ import (
 	"strings"
 	"sync"
 
-	"github.com/miguelmota/cointop/pkg/open"
+	"github.com/cointop-sh/cointop/pkg/open"
 	log "github.com/sirupsen/logrus"
 )
 
@@ -46,7 +46,7 @@ func TruncateString(value string, maxLen int) string {
 }
 
 // ClearSyncMap clears a sync.Map
-func (ct *Cointop) ClearSyncMap(syncMap sync.Map) {
+func (ct *Cointop) ClearSyncMap(syncMap *sync.Map) {
 	syncMap.Range(func(key interface{}, value interface{}) bool {
 		syncMap.Delete(key)
 		return true
