@@ -1,8 +1,8 @@
 package api
 
 import (
-	cg "github.com/miguelmota/cointop/pkg/api/impl/coingecko"
-	cmc "github.com/miguelmota/cointop/pkg/api/impl/coinmarketcap"
+	cg "github.com/cointop-sh/cointop/pkg/api/impl/coingecko"
+	cmc "github.com/cointop-sh/cointop/pkg/api/impl/coinmarketcap"
 )
 
 // NewCMC new CoinMarketCap API
