@@ -1,7 +1,7 @@
 package api
 
 import (
-	types "github.com/miguelmota/cointop/pkg/api/types"
+	"github.com/cointop-sh/cointop/pkg/api/types"
 )
 
 // Interface interface
@@ -13,9 +13,6 @@ type Interface interface {
 	GetGlobalMarketData(convert string) (types.GlobalMarketData, error)
 	GetCoinData(name string, convert string) (types.Coin, error)
 	GetCoinDataBatch(names []string, convert string) ([]types.Coin, error)
-	//GetAltcoinMarketGraphData(start int64, end int64) (types.MarketGraph, error)
-	//GetCoinPriceUSD(coin string) (float64, error)
-	//GetCoinMarkets(coin string) ([]types.Market, error)
 	CoinLink(name string) string
 	SupportedCurrencies() []string
 	Price(name string, convert string) (float64, error)
